@@ -16,6 +16,9 @@ parser.add_argument(
 parser.add_argument(
     '-d', '--directory', action='append', metavar='DIR', dest='paths',
     help="a directory to watch")
+parser.add_argument(
+    '-f', '--first', action='store_true',
+    help="run the command first and then wait for changes")
 parser.add_argument(
     '-D', '--delay', type=int, default=1,
     help="minimum seconds to wait before running the command again")
@@ -23,6 +26,9 @@ parser.add_argument(
     '-V', '--verbose', action='store_true',
     help="be more verbose")
 
+class FalseEvent(object):
+    name = None
+    pathname = None
 
 class Timer(object):
     """Call a function if $delay has passed since the last call"""
@@ -31,11 +37,14 @@ class Timer(object):
     def now():
         return datetime.datetime.now()
 
-    def __init__(self, delay, function):
-        self.delay = datetime.timedelta(seconds=delay)
+    def __init__(self, function, delay=1, first=None):
         self.function = function
+        self.delay = datetime.timedelta(seconds=delay)
         self.last_call = self.now() - self.delay
 
+        if first is not None:
+            self(FalseEvent())
+
     def __call__(self, *args, **kwargs):
         if (self.now() - self.last_call) > self.delay:
             self.function(*args, **kwargs)
@@ -43,10 +52,10 @@ class Timer(object):
 
 
 class Command(pyinotify.ProcessEvent):
-    def __init__(self, command, verbose=False, delay=0.5):
+    def __init__(self, command, verbose=False, delay=0.5, first=None):
         self.command = command
         self.verbose = verbose
-        self.timer = Timer(delay, self.run_command)
+        self.timer = Timer(self.run_command, delay=delay, first=first)
 
     def run_command(self, event):
         if self.verbose:
@@ -67,7 +76,8 @@ def main(mask=DEFAULT_INOTIFY_MASK):
 
     watch_manager = pyinotify.WatchManager()
     event_handler = Command(
-        command=args.command, delay=args.delay, verbose=args.verbose)
+        command=args.command, verbose=args.verbose, delay=args.delay,
+        first=(FalseEvent() if args.first else None))
     notifier = pyinotify.Notifier(watch_manager, event_handler)
 
     for path in (args.paths or ['.']):
